Examples
========

For more examples, which might not be part of the documentation, have a look at the
`repository <https://github.com/pyinduct/pyinduct/tree/master/examples>`_.

.. toctree::
    :maxdepth: 1

    transport_system
    rad_dirichlet_fem
    pipe_flow
    euler_bernoulli_beam
    rad_eq_const_coef
    string_with_mass
    pipe_flow
